@@ -1,17 +1,17 @@
-<?php /* Smarty version Smarty-3.1.21-dev, created on 2015-07-30 16:19:14
+<?php /* Smarty version Smarty-3.1.21-dev, created on 2016-12-14 16:16:13
          compiled from "ls:viewSearch.tpl" */ ?>
-<?php /*%%SmartyHeaderCode:89165210055ba4e82346c88-32641746%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
+<?php /*%%SmartyHeaderCode:11872149665851704da546b6-48539311%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
 $_valid = $_smarty_tpl->decodeProperties(array (
   'file_dependency' => 
   array (
     '7e5e1b40a6897e6cd2a4b75f034a469f40dd849c' => 
     array (
       0 => 'ls:viewSearch.tpl',
-      1 => 1414581297,
+      1 => 1472212472,
       2 => 'ls',
     ),
   ),
-  'nocache_hash' => '89165210055ba4e82346c88-32641746',
+  'nocache_hash' => '11872149665851704da546b6-48539311',
   'function' => 
   array (
   ),
@@ -25,8 +25,8 @@ $_valid = $_smarty_tpl->decodeProperties(array (
     'item' => 0,
     'label' => 0,
     'LSsearch' => 0,
-    'cid' => 0,
     'conf' => 0,
+    'cid' => 0,
     'page' => 0,
     'object' => 0,
     'start' => 0,
@@ -34,9 +34,9 @@ $_valid = $_smarty_tpl->decodeProperties(array (
   ),
   'has_nocache_code' => false,
   'version' => 'Smarty-3.1.21-dev',
-  'unifunc' => 'content_55ba4e82490115_26100221',
+  'unifunc' => 'content_5851704db02551_04783770',
 ),false); /*/%%SmartyHeaderCode%%*/?>
-<?php if ($_valid && !is_callable('content_55ba4e82490115_26100221')) {function content_55ba4e82490115_26100221($_smarty_tpl) {?><?php if (!is_callable('smarty_function_html_options')) include '/usr/share/php/smarty3/plugins/function.html_options.php';
+<?php if ($_valid && !is_callable('content_5851704db02551_04783770')) {function content_5851704db02551_04783770($_smarty_tpl) {?><?php if (!is_callable('smarty_function_html_options')) include '/usr/share/php/smarty3/plugins/function.html_options.php';
 if (!is_callable('smarty_function_cycle')) include '/usr/share/php/smarty3/plugins/function.cycle.php';
 ?><?php echo $_smarty_tpl->getSubTemplate ('ls:top.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>
 
@@ -158,7 +158,8 @@ foreach ($_from as $_smarty_tpl->tpl_vars['conf']->key => $_smarty_tpl->tpl_vars
 $_smarty_tpl->tpl_vars['conf']->_loop = true;
  $_smarty_tpl->tpl_vars['cid']->value = $_smarty_tpl->tpl_vars['conf']->key;
 ?>
-        <th class='LSobject-list'>
+        <th class='LSobject-list'<?php if ($_smarty_tpl->tpl_vars['conf']->value['cssStyle']) {?> style="<?php echo $_smarty_tpl->tpl_vars['conf']->value['cssStyle'];?>
+"<?php }?>>
         <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sort) {?>
           <a href='view.php?LSobject=<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->LSobject;?>
 &amp;sortBy=<?php echo $_smarty_tpl->tpl_vars['cid']->value;?>
@@ -206,8 +207,9 @@ foreach ($_from as $_smarty_tpl->tpl_vars['conf']->key => $_smarty_tpl->tpl_vars
 $_smarty_tpl->tpl_vars['conf']->_loop = true;
  $_smarty_tpl->tpl_vars['cid']->value = $_smarty_tpl->tpl_vars['conf']->key;
 ?>
-          <td class='LSobject-list'><?php echo $_smarty_tpl->tpl_vars['object']->value->{$_smarty_tpl->tpl_vars['cid']->value};?>
-</th>
+          <td class='LSobject-list'<?php if ($_smarty_tpl->tpl_vars['conf']->value['cssStyle']) {?> style="<?php echo $_smarty_tpl->tpl_vars['conf']->value['cssStyle'];?>
+"<?php }?>><?php echo $_smarty_tpl->tpl_vars['object']->value->{$_smarty_tpl->tpl_vars['cid']->value};?>
+</td>
           <?php } ?>
         <?php }?>
         <td class='LSobject-list LSobject-list-actions'>
